.. typer:: imagepipe.cli
    :builders: latex=text,html,svg:html=text,svg
    :show-nested:
    :make-sections:
    :width: 65

.. typer:: imagepipe.cli:sharpen
    :make-sections:
    :preferred: svg


References
----------

Cross references:

    * Check 0: :typer:`imagepipe`.
    * Check 1: :typer:`imagepipe-blur`.
    * Check 2: :typer:`imagepipe-crop`.
    * Check 3: :typer:`imagepipe-display`.
    * Check 4: :typer:`imagepipe-emboss`.
    * Check 5: :typer:`imagepipe-open`.
    * Check 6: :typer:`imagepipe-paste`.
    * Check 7: :typer:`imagepipe-resize`.
    * Check 8: :typer:`imagepipe-save`.
    * Check 9: :typer:`imagepipe-smoothen`.
    * Check 10: :typer:`imagepipe-transpose`.
    * Check 11: :typer:`sharpen <imagepipe sharpen>`.


Contents
--------

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   references
